# umlcharter
Python package for quick diagrams creation without a need to learn a new DSL.

The goal of this package is to provide a tool for a convenient and quick creation of the UML diagrams
in the popular DSLs like Mermaid, PlantUML, ZenUML, etc using a simple python constructions.

For details about the mentioned DSLs, please refer to the next links:
- [Mermaid](https://mermaid.js.org/)
- [PlantUML](https://plantuml.com/)
- [ZenUML](https://zenuml.com/)

For the examples of how this package can be used, please check the documentation:
- [Sequence Diagrams](docs/sequence_diagram/README.md)